@@ -27,7 +27,7 @@ use constant  AWS_CONTAINER_CREDENTIALS_URL          => 'http://169.254.170.2';
 
 use vars qw/$VERSION @EXPORT/;
 
-$VERSION = '1.0.7-2'; $VERSION=~s/\-.*$//;
+$VERSION = '1.0.8-0'; $VERSION=~s/\-.*$//;
 
 @EXPORT = qw/$VERSION/;
 
@@ -437,7 +437,7 @@ sub is_token_expired {
 
   if ( defined $expiration_date ) {
     # AWS recommends getting credentials 5 minutes prior to expiration
-    my $g = timegm(strptime($expiration_date, "%Y-%m-%dT%H:%M:%S%Z"));
+    my $g = timegm(strptime($expiration_date, "%Y-%m-%dT%H:%M:%S%z"));
     $g -= $window_interval * 60;
 
     my $seconds_left = $g - time;
